#
# spec file for package OpenColorIO
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define build_flavor %{nil}
%if "%{build_flavor}" == "ocio_tools"
%bcond_without ocio_tools
%else
%bcond_with    ocio_tools
%endif
# Ensure that libyaml-cpp version is the one that is built against
# See boo#1160171
%define yamlrequires %(rpm -q --requires yaml-cpp-devel | grep libyaml || echo aaa_base)
%define so_ver 2_4
%define pkg_name OpenColorIO
%if %{without ocio_tools}
Name:           OpenColorIO
%else
Name:           OpenColorIO-tools
%endif
Version:        2.4.2
Release:        1.1
Summary:        Color Management Solution Geared Towards Motion Picture Production
License:        BSD-3-Clause
Group:          Productivity/Graphics/Other
URL:            https://opencolorio.org/
Source0:        https://github.com/AcademySoftwareFoundation/OpenColorIO/archive/v%{version}.tar.gz
BuildRequires:  cmake >= 3.12
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libboost_headers-devel
BuildRequires:  libexpat-devel >= 2.2.8
BuildRequires:  liblcms2-devel >= 2.2
BuildRequires:  openexr-devel >= 3
BuildRequires:  pkgconfig
BuildRequires:  pystring-devel >= 1.1.3
BuildRequires:  python3-devel
BuildRequires:  python3-pybind11-devel
BuildRequires:  yaml-cpp-devel >= 0.6.3
BuildRequires:  pkgconfig(Imath) >= 3.1.1
BuildRequires:  pkgconfig(minizip-ng) >= 4.0.4
Recommends:     %{pkg_name}-doc = %{version}
%if %{with ocio_tools}
BuildRequires:  OpenImageIO-plugin-osl
BuildRequires:  OpenShadingLanguage-devel
BuildRequires:  python3-MarkupSafe
BuildRequires:  python3-Sphinx
BuildRequires:  python3-breathe
BuildRequires:  python3-recommonmark
BuildRequires:  python3-setuptools
BuildRequires:  python3-six
BuildRequires:  python3-sphinx-tabs
BuildRequires:  python3-sphinx_press_theme
BuildRequires:  python3-testresources
BuildRequires:  (OpenImageIO >= 2.1.9 with OpenImageIO < 3)
BuildRequires:  (OpenImageIO-devel >= 2.1.9 with OpenImageIO-devel < 3)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glut)
%endif

%description
OpenColorIO (OCIO) is a color management solution geared towards motion picture
production with an emphasis on visual effects and computer animation.

OCIO is compatible with the Academy Color Encoding Specification (ACES) and is
LUT-format agnostic, supporting many popular formats.

%package devel
Summary:        Development Files for OpenColorIO
Group:          Development/Libraries/C and C++
Requires:       libOpenColorIO%{so_ver} = %{version}
Recommends:     %{pkg_name}-doc = %{version}

%description devel
This package provides development libraries and headers needed to build
software using OpenColorIO.

%package -n %{pkg_name}-doc
Summary:        Documentation for OpenColorIO
Group:          Documentation/Other
BuildArch:      noarch

%description -n %{pkg_name}-doc
This package contains documentation for OpenColorIO.

%package -n libOpenColorIO%{so_ver}
Summary:        Complete Color Management Solution Geared Towards Motion Picture Production
Group:          System/Libraries
Requires:       %{yamlrequires}
# this is unfortunate and a fallout of properly naming the lib after fixing so_ver
Conflicts:      libOpenColorIO2_0 = 2.1.1
Conflicts:      libOpenColorIO2_0 = 2.1.2

%description -n libOpenColorIO%{so_ver}
OpenColorIO (OCIO) is a color management solution geared towards motion picture
production with an emphasis on visual effects and computer animation.

OCIO is compatible with the Academy Color Encoding Specification (ACES) and is
LUT-format agnostic, supporting many popular formats.

%package -n python3-OpenColorIO
Summary:        Python Bindings for OpenColorIO
Group:          Development/Libraries/Python
# python-OpenColorIO was last used at version 1.1.1
Provides:       python-OpenColorIO = %{version}
Obsoletes:      python-OpenColorIO < %{version}

%description -n python3-OpenColorIO
This package contains python bindings for OpenColorIO.

%prep
%autosetup -p1 -n %{pkg_name}-%{version}

# Fix library install location
sed -i 's|DESTINATION lib|DESTINATION %{_lib}|' src/OpenColorIO/CMakeLists.txt

%build
%cmake \
    -DCMAKE_CXX_STANDARD=17 \
    -DCMAKE_SKIP_RPATH=ON \
%ifnarch x86_64
    -DOCIO_USE_SSE=OFF \
%endif
%if %{with ocio_tools}
    -DOCIO_BUILD_DOCS=ON
%else
    -DOCIO_BUILD_APPS=OFF \
    -DOCIO_BUILD_DOCS=OFF
%endif
%cmake_build

%install
%cmake_install

# Remove stray static libs
rm -f %{buildroot}%{_libdir}/*.a

# Move documentation to the right location
mkdir -p %{buildroot}%{_docdir}/%{pkg_name}
cp *.md  %{buildroot}%{_docdir}/%{pkg_name}

# This shouldn't be needed
rm %{buildroot}%{_datadir}/ocio/setup_ocio.sh

%if %{without ocio_tools}
rm -rf %{buildroot}%{_docdir}/%{pkg_name}/
%else
mv %{buildroot}%{_datadir}/doc/OpenColorIO/html/ %{buildroot}%{_docdir}/%{pkg_name}/
rmdir %{buildroot}%{_datadir}/doc/OpenColorIO
rm -rf %{buildroot}%{_libdir}
rm -rf %{buildroot}%{_includedir}
%endif

%post -n libOpenColorIO%{so_ver} -p /sbin/ldconfig
%postun -n libOpenColorIO%{so_ver} -p /sbin/ldconfig

%if %{with ocio_tools}
%files
%license LICENSE
%{_bindir}/*
%doc %{_docdir}/%{pkg_name}/
%exclude %{_docdir}/%{pkg_name}/html/
%{_datadir}/ocio/

%files -n %{pkg_name}-doc
%{_docdir}/%{pkg_name}/html/
%else

%files devel
%{_includedir}/OpenColorIO/
%{_libdir}/pkgconfig/OpenColorIO.pc
%{_libdir}/cmake/OpenColorIO/
%{_libdir}/libOpenColorIO.so

%files -n libOpenColorIO%{so_ver}
%license LICENSE
%{_libdir}/libOpenColorIO.so.*

%files -n python3-OpenColorIO
%license LICENSE
%{python3_sitearch}/PyOpenColorIO/
%endif

%changelog
* Wed Mar 19 2025 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.4.2
  This is an ABI-compatible update for the 2.4.x series that
  includes all fixes and enhancements since the 2.4.1 release.
  With the 2.4.2 release, the "Preview" label is now removed from
  the ACES 2 implementation. After extensive collaboration with the
  ACES Output Transform working group, and our own testing, ACES 2
  support in OCIO is now officially released. We will continue to
  closely monitor your feedback on this new tech.
  A large part of the work since the 2.4.1 release was an attempt
  to optimize the ACES 2 algorithms. ACES 2 is still substantially
  slower than ACES 1 on CPU and somewhat slower on GPU. But the
  optimization efforts did yield a roughly 25%% speedup over the
  2.4.1 release, along with a simplification of the code. Special
  thanks to Kevin Wheatley and Remi Achard for leading this work.
  In conjunction with the 2.4.2 release, the OCIO ACES configs
  working group has released the ACES 2.0 configs for OCIO. Special
  thanks to Thomas Mansencal for leading this work. The configs are
  not yet built into the library itself and may be downloaded from
  this link.
  Bug fixes and enhancements:
  - PR #2127, ACES 2.0 Output Transform performance optimization
  - PR #2112, Absolute paths not working through ConfigIOProxy
  - PR #2128, Add missing setConfigIOProxy call to the Python API
  - PR #2117, Fix metal backend's generated shaders with
    float/int/constant array performance
  - PR #2121, Integrate matrix multiplication fix from OSL
  - PR #2120, Change recommended Imath version to 3.1.12
  - PR #2109, Fix issue with ocio_depts handling spaces in file
    paths
  - PR #2132, NaN fix for the ACES 2 inverse output transforms
* Sat Feb 15 2025 Marcus Rueckert <mrueckert@suse.de>
- bump openexr to >= 3 match the rest of the stack
- Have an explicite BR for pkgconfig(Imath) and do not rely on it
  being pulled via openexr
* Sat Feb  1 2025 Marcus Rueckert <mrueckert@suse.de>
- Lock OpenImageIO to < 3
* Fri Dec 13 2024 Marcus Rueckert <mrueckert@suse.de>
- apparently the 2.4.0 tarball for a moment had the version set to
  2.5.0 when i grabbed it. now it was fixed down to 2.4.x again.
  so the soversion is downgraded again to 2.4
  https://github.com/AcademySoftwareFoundation/OpenColorIO/issues/2073
* Thu Dec 12 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.4.1
  This is an ABI-compatible update for the 2.4.x series that
  includes all fixes since the 2.4.0 release.
  The ACES 2 implementation is still considered a Preview Release.
  OCIO contributors are working closely with the ACES 2 Output
  Transforms working group and a 2.4.2 release is planned for early
  March to finalize the ACES 2 algorithm implementation. A preview
  of the ACES 2 config files (compatible with OCIO 2.4.1) is
  available here.
  - Bug fixes and minor enhancements:
  - PR #2068, Fix views/display sub-menus in OCIO Display app for
    ACES 2 compatibility
  - PR #2095, Add "DISPLAY - CIE-XYZ-D65_to_DisplayP3-HDR"
    built-in transform
  - PR #2104, Optimizer detects pair inverses before combining
    multiple op pairs
  - PR #2074, Text format (e.g., Iridas cube) parsing
    optimizations
  - PR #2106, Fix Python wheel macOS workflow and make
    OCIO_PYTHON_LOAD_DLLS_FROM_PATH opt-in
  - PR #2090, Fix bit-depth attribute for inverse LUTs when
    writing CTFs
  - PR #2078, Added more accurate DX11 HLSL shading language enum
    name
  - PR #2077, Match ACES 2.0 shader resource suffix format to
    regular LUTs
  - PR #2096, Fixed range function error in nuke colorlookup
    examples
  - Build, documentation, and website enhancements:
  - PR #2072, Enable parallel source file compilation on MSVC
  - PR #2085, Update doc building instructions
  - PR #2084, Photoshop now supports OCIO
  - PR #2088, Add Disguise to list of supported applications
  - PR #2069, Move GPU LUT files into the tests dir
  - PR #2102, Fix broken Linux and Mac CI workflow
* Tue Oct  1 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.4.0
  This is the main new feature release for this year and is the
  base version for the CY2025 VFX Reference Platform (which
  specifies 2.4.x).
  The headline feature this year is a Preview Release of ACES 2
  Output Transform support. This is a work-in-progress and we
  anticipate that both the processing results and the API will
  likely change somewhat before it is finalized. Our goal is to do
  that by the end of the year in a 2.4.x release.
  Ideally, application developers will introduce 2.4.0 into their
  testing programs now and then update to the latest 2.4.x release
  available before shipping next year.
  This documentation page explains the new features in this
  release.
  - Major new features:
  - PR #1983, ACES 2 Output Transforms
  - PR #2039, Add updated CG and Studio configs for ACES 1.3
  - PR #1941, Builtin Transform for Apple Log
  - PR #1914, OCIOView: Chromaticities inspector
  - PR #1932, Add AVX512 accelerated LUT1D and LUT3D
  - PR #2029, Add new FixedFunction and Builtin Transforms
  - Bug fixes and minor enhancements:
  - PR #1988, Add NamedTransform support for ocioconvert
  - PR #2051, Add DCDM displays and improve HLG OOTF
    implementation
  - PR #2052, Add Wheels for Python 3.13
  - PR #2006, OCIOView: App mode, tests, color space menus, bug
    fixes
  - PR #1966, OCIOView: Updates & fixes
  - PR #1985, OCIOView: Fix color_space_to_rgb_colourspace
    function usage
  - PR #1962, Add function to check if an extension is supported
    by FileTransform
  - PR #2059, Add hasAlias method to ColorSpace and
    NamedTransform
  - PR #2038, Add bit-depth flag to ocioconvert
  - PR #1981, Modify half-domain LUT1D GPU shader to improve zero
    handling
  - PR #1976, Allow read and write of file rules without color
    space validation
  - PR #2026, Update supported apps info for Photoshop and After
    Effects
  - PR #2022, Add Photoshop Beta support section to documentation
  - PR #2025, Remove legacy Photoshop and After Effects plug-ins
  - PR #2062, Add Python usage example for viewing pipeline on
    CPU
  - PR #2037, Add TouchDesigner to supported apps list
  - PR #2024, Fix typo in documentation
  - PR #1989, Improve GradingPrimary documentation
  - PR #2020, Allow building with gcc-15
  - PR #2019, Harden test temp folder handling
  - PR #1987, Use the correct locale include for Darwin
  - PR #1977, TSC & Committer update, add Mark & Cuneyt, create
    an emeritus section
  - PR #1961, Replaced deprecated Carbon framework with ColorSync
    and CoreGraphics
  - PR #1960, Add ociocpuinfo utility
  - PR #1950, Fix CPU unit test failures on recent macOS ARM
    platforms
  - PR #2060, Update documentation for 2.4 release
  - Build process enhancements:
  - PR #2053, Add Docker images for VFX Platform 2024 to CI
  - PR #2058, Fix Platform Latest CI
  - PR #2028, Add config file to fix ReadTheDocs builds
  - PR #1990, Fix for GitHub Actions node.js glibc issue
  - PR #1986, Improve minizip-ng installer CMake
  - PR #1945, Various CI workflow fixes
  - PR #1980, Improve Windows batch files to find installed
    Visual Studio location
* Fri May 24 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.3.2
  This is an ABI-compatible update for the 2.3.x series that
  includes all fixes since the 2.3.1 release.
  In particular, this release fixes two crashes:
  Certain older (generally 7-12 year old) CPUs including Intel
  x86-64 (Sandy Bridge and Ivy Bridge) and Intel Atom
  (Goldmont/Apollo Lake) microarchitectures that support SSE 4.2
  SIMD instructions but do not support the initial AVX set and
  XSAVE, or other CPUs where the OS has disabled AVX and XSAVE
  support, will crash when trying to evaluate a Lut1D or Lut3D in
  OCIO libraries compiled with SSE enabled (which is the default).
  More recent CPUs (e.g., those supporting AVX2 or higher) should
  not be affected.
  Users of the Linux Python bindings via PyPI will crash when
  trying to use OCIO from within another application that has been
  compiled with the new libstdc++ ABI, per the requirements of the
  VFX Platform for CY2023 and CY2024.
  Bug fixes and minor enhancements:
  - PR #1935, Prevent trying to use AVX instructions on certain
    CPUs that don't support them
  - PR #1933, Add manylinux_2_28 Python wheels for compliance with
    the current VFX Platform libstdc++ ABI
  - PR #1929, Fix ssse3 detection typo
  - PR #1921, Fix build break with custom PyString installs by
    always using system include pystring.h
  - PR #1924, Fix narrowing conversion error in unit test on
    riscv64
  - PR #1925, Enhance the ociochecklut command-line tool to print
    the output after each step
- drop a95febc7.patch: fixed in update
* Wed Jan 24 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to fix build on aarch64:
  * a95febc7.patch
* Fri Jan 19 2024 Hans-Peter Jansen <hpj@urpla.net>
- Upstreamed patches 0001-Fix-detection-of-yaml-cpp-0.8.patch
  and gcc12_fix.patch removed
* Thu Jan 18 2024 Marcus Rueckert <mrueckert@suse.de>
- Move OpenImageIO buildrequires back into the tools section to
  avoid loop
* Thu Jan 18 2024 Marcus Rueckert <mrueckert@suse.de>
- Bump minizip-ng to 4.0.4 as it avoids some weird compiler
  warnings seen with older versions
* Mon Jan 15 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.3.1
  Bug fixes and minor enhancements:
  - PR #1898, Add Python 3.12 wheels
  - PR #1913, Improve heuristics for finding known color spaces
  - PR #1886, Fix missing Default View Transform on equal operator
  - PR #1904, Fix env serialization for v1 configs
  - PR #1873, Fix missing cache id reset on look update
  - PR #1896, Skip processor concatenation if the display color
    space is also data
  - PR #1855, Fix regression in cccid handling when no value is
    supplied
  - PR #1849, Python bindings source builds failing to load
    libOpenColorIO
  - PR #1905, Fix NamedTransform context var issue
  - PR #1845, Improve ocioview curve inspector
  - PR #1853, Improve ocioview mac support and simplify
    dependencies
  - PR #1882, Remove circular import caused by typing annotations
  - PR #1888, ICC Profile load issue caused by improper use of
    std::isspace
  - PR #1847, Add some small arm neon optimizations
  - PR #1842, Fix support for X86 32-bit
  - PR #1848, Add links to new release notes documentation
  - PR #1892, Fix spelling errors in documentation
  Build enhancements:
  - PR #1907, Fix yaml-cpp build issues
  - PR #1902, Improve compatibility with minizip-ng COMPAT mode
  - PR #1901, Improve handling of pystring include dir
  - PR #1899, Restore GPU workflow and minor updates to CI
  - PR #1891, Simplify the Findyaml-cpp module
  - PR #1890, Tentative fix for the doxygen installation in the
    Windows CI
  - PR #1861, Correctly recover CXX_FLAGS in CheckSupportSSE2.cmake
* Mon Jan 15 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.3.0
  This is the main new feature release for this year and is the
  base version for the CY2024 VFX Reference Platform (which
  specifies 2.3.x).
  We anticipate making an ABI-compatible 2.3.x release near the end
  of the year that will fix any issues found with the new features
  as the 2.3.0 library gets more widely tested. Ideally,
  application developers will introduce 2.3.0 into their testing
  programs now and then update to the latest 2.3.x release
  available before shipping next year.
  This documentation page explains the new features in this
  release.
  Major new features:
  - PR #1816, Add new ocioview config visual editor app (alpha)
  - PR #1687, Utilize AVX SIMD intrinsics to accelerate Lut1D and
    Lut3D performance
  - PR #1828, Utilize Neon SIMD intrinsics and improve Universal
    Build support for macOS
  - PR #1788, Enhanced methods to find an equivalent color space
    between configs
  - PR #1802, Add command-line apps to Python Wheel
  - PR #1808, Add GetProcessorFromConfigs variants for displays and
    views
  - PR #1762, Disallow use of 1D textures for Lut1D ops in the GPU
    renderer
  - PR #1791, Add clear Processor cache function to accomodate
    changes to existing LUT files
  - PR #1773, Add cg-config-latest & studio-config-latest
    short-cuts to built-in configs
  - PR #1812, Add built-in transform for Display P3 and bump config
    version
  Bug fixes and minor enhancements:
  - PR #1792, Add isInactiveColorSpace and getRoleColorSpace
    methods
  - PR #1832, Add hasDynamic method to CPUProcessor and allow OSL
    language output from Python
  - PR #1829, Fix named transform validation issue
  - PR #1779, Fix GradingPrimary bypass and allow easier comparison
    in Python
  - PR #1759, Allow PyOpenColorIO module to load DLLs from Windows
    PATH env var
  - PR #1780, Improve DisplayViewTransform error message and add
    more unit tests
  - PR #1786, Remove inactive color space warnings from unit test
    output
  - PR #1822, Remove additional color space warnings from unit test
    output
  - PR #1833, Update Python docs for new texture dimensions API
  - PR #1812, Fix error in Baker documentation related to LUT
    inversion
  - PR #1803, Add Thomas and Zach to the TSC
  - PR #1782, Add 3ds Max as a supported app
  Build process enhancements:
  - PR #1777, Add CMake support for minimum and recommended
    versions of dependencies
  - PR #1813, Add VFX Platform 2023 to CI Linux build matrix
  - PR #1778, Improve Python Wheel packaging
  - PR #1790, Make OpenColorIO usable as a sub-project using
    CMake's FetchContent
  - PR #1806, Support minizip-ng 4 API
  - PR #1823, CMake fixes for yaml-cpp affecting vcpkg
  - PR #1793, Change min ZLib version to 1.2.8
  - PR #1826, Adjust to change in Sphinx breaking documentation
    builds
  - PR #1809, Adjust to change in Doxygen groups to fix
    documentation build
  - PR #1797, Adjust urllib3 version to fix CI and
    dependencies-latest workflows
  - PR #1770, Update GitHub Actions workflows
  - PR #1795, OSL-related fix for dependencies-latest workflow on
    macOS
  - PR #1783, Docutils version fix for dependencies-latest workflow
  - PR #1714, Fix CI warnings / deprecations
* Mon Jan 15 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.2.1
  Bug fixes and minor enhancements:
  - PR #1743, Fix inverse Lut1D optimization issue (may affect
    identity Look transforms in camera log process spaces)
  - PR #1742, Improve naming of ICC-based virtual displays on
    Windows
  - PR #1741, Fix Python ARM Wheel (now works on M1-based Macs)
  - PR #1738, Update documentation for 2.2 release
  - PR #1734, Fix issue with isColorSpaceLinear function (to avoid
    crash when color space doesn't exist)
  - PR #1726, Processor cache does not detect context variable
    changes in FileTransform cccid string
  - PR #1723, Replace "texture2D" function with "texture" for GLSL
    1.3 (allows use of GLSL 1.3)
  Build enhancements:
  - PR #1736, OCIO CMake improvements
  - PR #1729, Hiding minizip-ng symbols on Mac
  - PR #1725, Fix issue with minizip build
  - PR #1721, CheckSupportSSE2: Fix sse flags unexpected
    propagation
  - PR #1720, Configure the OpenColorIO.pc file on Windows
* Mon Jan 15 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.2.0
  This is the main new feature release for this year and is the
  base version for the CY2023 VFX Reference Platform (which
  specifies 2.2.x).
  We anticipate making an ABI-compatible 2.2.1 release near the end
  of the year that will fix any bugs found with the new features as
  the 2.2.0 library gets more widely tested.
  New features:
  - PR #1659, Build the new ACES CG and Studio configs into the
    library itself
  - PR #1696, Allow OCIO configs to be archived, introducing the
    .ocioz file format
  - PR #1710, Convert to or from a known external color space
  - PR #1703, Add a method to query whether a color space is linear
  - PR #1637, Address circular build dependency between OCIO and
    OpenImageIO
  Noteworthy bug fixes and enhancements:
  - PR #1711, Make the interchange roles required for config
    versions 2.2 or higher
  - PR #1691, Add support for ICC Parametric curves type 1-4
  - PR #1689, Add getProcessor calls that take a NamedTransform
  - PR #1604, Add preliminary support for ACES Metadata Files (AMF)
  - PR #1693, Add NamedTransform support for Baking and fix
    crosstalk issue
  - PR #1704, Add Built-in Transforms for ARRI LogC4 and Canon
    curves
  - PR #1706, Add Python 3.11 wheels
  - PR #1712, Fix atan2 issue with ACES viewing transforms in HLSL
  - PR #1656, Speed up config ID hashing (replace md5 with xxhash)
  - PR #1684, Allow ocioconvert, ociowrite, ocioperf to invert a
    DisplayViewTransform
  - PR #1646, Provide scripts to facilitate building OCIO on
    Windows
  - PR #1630, Improve iridas_cube parsing speed
  - PR #1605, Add Python source distribution package for PyPI
  - PR #1598, Add DisplayViewTransform support to Baker
  - PR #1516, Default to C++ 14 and remove OIIO from ocioperf
  - PR #1532, Update default branch name to "main"
  Other fixes and minor enhancements:
  - PR #1715, Fix missing warnings issue with ociocheck
    command-line tool
  - PR #1713, Update Built-in configs with official 1.0.0 CG and
    Studio release
  - PR #1708, Enforce GL_NEAREST with GPU tetrahedral interpolation
  - PR #1697, Built fix (strtof_l) for MinGW
  - PR #1695, Add anchorpoint to supported applications
  - PR #1694, Log OCIO version for debugging purposes
  - PR #1692, Fix OpenEXR build on ninja
  - PR #1684, Fix for const literals in HLSL
  - PR #1678, Build fix (from_chars, strtol_l) for those using the
    musl-libc library
  - PR #1669, Correct http links to https
  - PR #1647, Build fixes for MS Visual Studio 2022
  - PR #1636, Print version in cmake find_package
  - PR #1635, Adjust 'family' description in OpenColorIO.h
  - PR #1632, Fix "requirement" typo in installation.rst
  - PR #1599, Minor build and CI fixes
  - PR #1594, Fix cmake issue with Windows Unicode support
  - PR #1542, Build fixes for C++ 20
  - PR #1596, Update Carol Payne as TSC Chair in GOVERNANCE.md
  - PR #1498, Add Rémi Achard to GOVERNANCE.md & COMMITTERS.md
* Mon Jan 15 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.1.3
  - PR #1743, Fix inverse Lut1D optimization issue (may affect
    identity Look transforms in camera log process spaces)
  - PR #1726, Processor cache does not detect context variable
    changes in FileTransform cccid string
  - PR #1723, Replace "texture2D" function with "texture" for GLSL
    1.3 (allows use of GLSL 1.3)
  - PR #1712, Fix atan2 argument order for HLSL (may affect ACES
    output transforms on Windows)
  - PR #1697, MinGW: Work around lack of strtof_l for
    local-independent parsing (allows compiling with MinGW)
* Wed Aug 30 2023 Christophe Marin <christophe@krop.fr>
- Add patch:
  * 0001-Fix-detection-of-yaml-cpp-0.8.patch
* Wed May 31 2023 Hans-Peter Jansen <hpj@urpla.net>
- add OpenShadingLanguage, OpenImageIO-plugin-osl and python3-six
  build deps for tools build
- remove outdated BuildIgnore: libOpenColorIO2_0
* Mon Jul 18 2022 Hans-Peter Jansen <hpj@urpla.net>
- explicitly conflict the wrongly named libs
- don't build tools in basic build stage
* Sun Jul 17 2022 Hans-Peter Jansen <hpj@urpla.net>
- raise c++ standard to 17
- disable rpath, resulting in a hard build failure now
- add opengl deps for gpu support
- broaden stray static libs removal (due to gpu enablement)
* Sat Jul 16 2022 Hans-Peter Jansen <hpj@urpla.net>
- fix so version pkg naming
* Sat Jun  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.1.2:
  * Fix half-domain Lut1D issue for certain values above HALF_MAX
  * Python copy support
  * Fix support for ARM64 macOS Python wheels
  * Improve OpenImageIO dependency management of Imath headers
  * Improve CMake and library install step
  * Remove "expat" symbols
  * Improve the GPU unit test framework
  * Improve the OSL integration
  * Propagate Android CMake configuration to external projects
* Thu May 12 2022 Asterios Dramis <asterios.dramis@gmail.com>
- Added a patch "gcc12_fix.patch" to fix compilation with GCC12.
* Tue Mar 15 2022 Dirk Müller <dmueller@suse.com>
- adjust license declaration to be BSD-3-Clause only based on
  licensereview in https://build.opensuse.org/request/show/951516
* Fri Jan 28 2022 Dirk Müller <dmueller@suse.com>
- update to 2.1.1:
  * Adds Metal Shading Language generation support to the GPU renderer
  * Adds OpenGL ES generation support to the GPU renderer
  * After Effects plug-in updates
  * Adds Metal support to ociodisplay and enables running GPU tests with Metal backend
  * Fix issue resulting in NaNs when inverting ACES Output Transforms
  * Implement locale-agnostic number parsing
  * Fix issue causing configs to fail validation with certain LUT search paths
  * Python 3.10 macOS wheels
  * Remove extra commas when writing a CDL in CLF file format
  * Fixes Unicode paths on Windows
  * Fix issues with OSL generation and improve the OSL unit test framework
  * Add Python GPU renderer implementation example
  * Improvement to color space metadata in ocioconvert exports
  * Better manage Imath dependency
  * Add ACES 1.3 Gamut Compression implementation
  * Add OpenFX OCIO plug-in framework and examples
  * Add Python wheel generation and support for PyPI
  * Add preliminary support for emitting Open Shading Language
  * Add Imath 3 support for Half dependency and update CI workflow
  * Increment version number for the config file and CTF formats to 2.1
  * Allow apps to use getColorSpaceFromFilePath even for v1 configs and
    deprecate parseColorSpaceFromString
  * Add getDefaultView(display, colorspaceName) method
  * Fix problem rendering to integer pixel layouts when there is a no-op
  * Update CLF test files, add Python scripts for CLF implemenation guide
  * drop fix-armv7.patch, OpenColorIO-openexr3.patch: upstream
* Wed Dec  8 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to fix build on armv6/7:
  * fix-armv7.patch
* Mon Dec  6 2021 Dirk Müller <dmueller@suse.com>
- update to 2.0.2:
  This is an ABI compatible update for the 2.0.x series that includes the
  relevant bug fixes from the 2.1 release.
  Noteworthy bug fixes and enhancements:
  * Allow apps to use getColorSpaceFromFilePath even for v1 configs and
    deprecate parseColorSpaceFromString
  * Fix problem rendering to integer pixel layouts when there is a no-op
  * Update CLF test files, add Python scripts for CLF implemenation guide
- Rebased OpenColorIO-openexr3.patch.
* Tue Sep  7 2021 Marcus Rueckert <mrueckert@suse.de>
- only build the documentation in the ocio_tools case:
  - move BuildRequires into the %%if
  - explicitely disable doc building in the library build case
* Tue Sep  7 2021 Marcus Rueckert <mrueckert@suse.de>
- A probably better fix for solving the build cycle. First build
  will only build all the libraries, 2nd build the cmdline tools
* Tue Sep  7 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not depends on OpenImageIO, in order to break up a build
  cycle (boo#1190237).
* Fri Aug 20 2021 pgajdos@suse.com
- fix build with openexr3
- added patches
  https://aur.archlinux.org/cgit/aur.git/tree/opencolorio-openexr3.patch?h=opencolorio-qfix
  + OpenColorIO-openexr3.patch
* Tue Jul 27 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix 64bit library install location for aarch64 and ppc64* as
  well, not only for x86_64
* Thu Jul 22 2021 Hans-Peter Jansen <hpj@urpla.net>
- provide/obsolete python-OpenColorIO
* Tue Jul 13 2021 Hans-Peter Jansen <hpj@urpla.net>
- Retain the %%{yamlrequires}
* Mon Jul 12 2021 Hans-Peter Jansen <hpj@urpla.net>
- Use %%cmake_build
* Mon Jul  5 2021 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 2.0.1:
  Unfortunately, it's missing a changelog, check GH release notes:
  https://github.com/AcademySoftwareFoundation/OpenColorIO/releases/tag/v2.0.1
- Removed all patches:
  * OpenColorIO-setuptools.patch
  * 0003-Fix_Linux_compilation.patch
  * 0004-Fix_build_with_GCC-8.patch
  * 0005-Fix_build_with_yaml-cpp0.6.patch
  None of them applied anymore
- Remove tarball crippling, doesn't contain Pygments anymore
- Update build dependencies
- Fix 64bit library install location
- cmake and python devel files disappeared
* Thu Jul  1 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update Requires of devel package to python3-devel
* Fri Jan 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use python3 to produce the package due to python2 removal
* Wed Jan  8 2020 Dave Plater <davejplater@gmail.com>
- Work around yaml-cpp's bad abi versioning by requiring the version
  it was built against. See boo#1160171
* Fri Apr 19 2019 Asterios Dramis <asterios.dramis@gmail.com>
- Update to version 1.1.1:
  * Added optional compatibility for building apps with OpenImageIO
    1.9+
  * Added USE_SSE checks to fix Linux build failure
  * getDisplays() result ordering now matches the active_displays
    config definition or OCIO_ACTIVE_DISPLAYS env var override.
  * Fixed incorrect getDefaultDisplay()/getDefaultView() result
    when OCIO_ACTIVE_DISPLAYS or OCIO_ACTIVE_VIEWS env vars are
    unset.
  * Fixed Windows-specific GetEnv() bug
  * Fixed Windows and MacOS CI failure cases
  * Updated mail list URLs to aswf.io domain
  From version 1.1.0:
  * libc++ build fixes
  * Added support for YAML > 5.0.1
  * YAML and TinyXML patch fixes
  * Clang visibility fix
  * Added write support for Truelight LUTs
  * Improved OCIOYaml
  * Python string corruption fix
  * Added support for CDL
  * Updated documentation
  * Added args/kwargs support to Python MatrixTransform
  * Added description field to Look objects
  * Improved Python 3 compatibility
  * CSP file read fix
  * Added Linux, MacOS, and Windows continuos integration
  * Improved 1D LUT extrapolation
  * Improved 1D LUT negative handling
  * Improved Windows build system
  * Improved cross-platform build system
  * Undefined role crash fix
  * After Effects plugin updated
  * Added reference Photoshop plugin
  * Added reference Docker image
- Added the following patches:
  * OpenColorIO-setuptools.patch (Use external python-setuptools
    for building)
  * 0003-Fix_Linux_compilation.patch
  * 0004-Fix_build_with_GCC-8.patch
  * 0005-Fix_build_with_yaml-cpp0.6.patch
- Added new build requirements libboost_headers-devel and
  python-setuptools.
- Removed support for openSUSE <= 12.2.
* Sat Jan 31 2015 asterios.dramis@gmail.com
- Update to version 1.0.9:
  * CDL cccid supports both named id and index lookups
  * ociobakelut / ocioconvert updates
  * FreeBSD compile dixes
  * FileTransform disk cache allows concurrent disk lookups
  * CSP windows fix
  * Python 3 support
  * Fix envvar abs/relative path testing
  * Can explicitly declare config envvars
  * gcc44 compile warning fixes
- Updated crippled tarball instructions (RegexMatcher.ns2 no longer exists).
- Added new build requirement python-MarkupSafe.
* Sat Jul  6 2013 asterios.dramis@gmail.com
- Use internal yaml-cpp until OpenColorIO is ported to yaml-cpp >= 0.5.0
  currently in Factory.
* Wed May 22 2013 asterios.dramis@gmail.com
- Updated license to "BSD-3-Clause and GPL-2.0+".
- Removed non OSS licensed files from source package - use a crippled tarball
  (bnc#821203).
* Fri Mar 22 2013 asterios.dramis@gmail.com
- Use a proper source URL.
* Thu Mar  7 2013 asterios.dramis@gmail.com
- Build the doc subpackage as noarch.
* Thu Feb 21 2013 asterios.dramis@gmail.com
- Use external yaml-cpp library only for openSUSE > 12.2.
* Thu Feb 21 2013 asterios.dramis@gmail.com
- Initial release (version 1.0.8).
